@@ -4,7 +4,7 @@ import threading
 from datetime import datetime
 from typing import Dict, Any
 
-from dbt import flags
+from dbt.flags import env_set_truthy
 from dbt.adapters.factory import get_adapter
 from dbt.clients.jinja import extract_toplevel_blocks
 from dbt.config.runtime import RuntimeConfig
@@ -24,6 +24,9 @@ from dbt.task.run import RunTask
 from .base import RPCTask
 
 
+SINGLE_THREADED_HANDLER = env_set_truthy('DBT_SINGLE_THREADED_HANDLER')
+
+
 def add_new_refs(
     manifest: Manifest,
     config: RuntimeConfig,
@@ -33,7 +36,7 @@ def add_new_refs(
     """Given a new node that is not in the manifest, insert the new node
     into it as if it were part of regular ref processing.
     """
-    if config.args.single_threaded or flags.SINGLE_THREADED_HANDLER:
+    if config.args.single_threaded or SINGLE_THREADED_HANDLER:
         manifest = manifest.deepcopy()
     # it's ok for macros to silently override a local project macro name
     manifest.macros.update(macros)
@@ -118,7 +121,8 @@ class RemoteRunSQLTask(RPCTask[RPCExecParameters]):
             manifest=self.manifest,
             root_project=self.config,
         )
-        rpc_node = rpc_parser.parse_remote(sql, self.args.name)
+
+        rpc_node = rpc_parser.parse_remote(sql, self.args.name, self.args.language)
         add_new_refs(
             manifest=self.manifest,
             config=self.config,
@@ -152,6 +156,7 @@ class RemoteRunSQLTask(RPCTask[RPCExecParameters]):
         self.args.name = params.name
         self.args.sql = params.sql
         self.args.macros = params.macros
+        self.args.language = params.language
 
     def handle_request(self) -> RemoteExecutionResult:
         # we could get a ctrl+c at any time, including during parsing.
